# Introduction

Workflow for running PennCNV analysis with Illumina platform files.

# Requirements

  - You will need the following files:
    - Illumina Final Report file (CSV) should exist in the git directory (see Installation).
    - SNP Map (from Illumina results, not the MAP from PLINK) file should exist in the git directory (see Installation).
      - This SNP Map file has the following header: ```Index	Name	Chromosome	Position	GenTrain Score	SNP	ILMN Strand	Customer Strand	NormID```
    - Illumina CNV report, which you can generate from [GenomeStudio](https://support.illumina.com/array/array_software/genomestudio/downloads.html) >= 2.x
      - This report file has the following header: ```SNP Name,Sample ID,B Allele Freq,Log R Ratio```
  - GC file name
  - RefGene URL (required by PennCNV scan_region.pl script). 
    - You can obtain both GC and copy URL from the [UCSC site](http://hgdownload.cse.ucsc.edu/downloads.html)

# Notes

  - If you filtered your Illumina results through PLINK (i.e. PED/MAP files) you will need to update the input files by running the build script in the step 1) (see Usage).
  - The build script automatically downloads and install [Pharo](https://www.pharo.org) and required libraries.
  
# Output files

  - PFB (Population B-Allele Frequency) file : .pfb (generated by compile_pfb.pl)
  - GC Model File : .gcmodel (generated by cal_gc_snp.pl)
  - Output directory with:
    - Signal intensity PennCNV results
    - JPEG visualizations of signal itensity files for each individual
    - BED files for loading into UCSC Genome Browser for each individual

# Installation

  - Download and install [PennCNV](http://penncnv.openbioinformatics.org/en/latest/user-guide/download/)
  - Open a terminal or [GitBash](https://git-scm.com/downloads), create and cd to a working directory for example: 
    - ```mkdir /c/bio_jobs; cd /c/bio_jobs```
  - Clone this repository. 
    - ```git clone https://github.com/hernanmd/PennCNV.Illumina.git```
  - Put your Illumina Final Report CNV results into the recently created directory "PennCNV.Illumina" 
    - JobID_FinalReportCNV.zip (do not uncompress).
  - Put both your original PED/MAP files and already filtered PED/MAP files into the directory.
    
 # Usage
 
The workflow involves running two scripts: 1) Prepare input files for PennCNV and 2) Run the PennCNV scripts.
Let's assume the name of your PED/MAP files is MySamples

## Prepare input files

```bash
./build_penncnv.sh JobID_FinalReportCNV.zip MySamples MySamples.fltr
```
  - First parameter is a ZIP files containing Illumina Final Report CNV file.
  - Second parameter is the name of the PED/MAP file without the extension.
  - Third parameter is the name of the filtered PED/MAP file without the extension.
  - Fourth parameter is the Illumina SNP_Map.txt (tab-delimited) file.

## Run PennCNV scripts

Edit the script run_penncnv.sh to adjust parameters and/or enable downloading the GC file (required for the first time): 

```
./run_penncnv.sh PrjName MySamples.fltr.ped
```

  - First parameter is the project name, it could be anything to identify your output files.
  - Second parameter is the Illumina Final Report CNV (CSV file) filtered in the previous step.
  
 # Issues
 
   - Please report issues here: [https://github.com/hernanmd/PennCNV.Illumina/issues](https://github.com/hernanmd/PennCNV.Illumina/issues) describing:
     - Your platform (Operating System, Architecture: i686, x64)
     - The command you have used.
     - The produced output. 
       - To copy text from MSYS2 or GitBash console, please go to the upper left menu and select Edit and then Mark.
 
 # License
 
This software is licensed under the MIT License.

Copyright Hernán Morales Durand, 2018.

Permission is hereby granted, free of charge, to any person obtaining  a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, 
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF 
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY 
CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, 
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

Authors

Hernán Morales Durand
